package com.ruoyi.dxp.mapper;

import java.util.List;
import com.ruoyi.dxp.domain.Topic;

/**
 * 专题Mapper接口
 * 
 * @author jy
 * @date 2022-11-06
 */
public interface TopicMapper 
{
    /**
     * 查询专题
     * 
     * @param id 专题主键
     * @return 专题
     */
    public Topic selectTopicById(Long id);

    /**
     * 查询专题列表
     * 
     * @param topic 专题
     * @return 专题集合
     */
    public List<Topic> selectTopicList(Topic topic);

    /**
     * 新增专题
     * 
     * @param topic 专题
     * @return 结果
     */
    public int insertTopic(Topic topic);

    /**
     * 修改专题
     * 
     * @param topic 专题
     * @return 结果
     */
    public int updateTopic(Topic topic);

    /**
     * 删除专题
     * 
     * @param id 专题主键
     * @return 结果
     */
    public int deleteTopicById(Long id);

    /**
     * 批量删除专题
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTopicByIds(Long[] ids);
}
